.. all-saltext.elasticsearch.modules:

_________________
Execution Modules
_________________

.. currentmodule:: saltext.elasticsearch.modules

.. autosummary::
    :toctree:

    elasticsearch6_mod
    elasticsearch8_mod
    elasticsearch9_mod
